@@ -608,7 +608,7 @@ MOS_STATUS CodechalInterfacesXe_Xpm_Plus::Initialize(
             if (CodecHalUsesVdencEngine(info->CodecFunction))
             {
             #ifdef _HEVC_ENCODE_VDENC_SUPPORTED
-            #ifdef _APOGEIOS_SUPPORTED
+            #ifdef _MEDIA_RESERVED
                 bool apogeiosEnable = true;
                 MOS_USER_FEATURE_VALUE_DATA         userFeatureData;
                 MOS_ZeroMemory(&userFeatureData, sizeof(userFeatureData));
